#!/usr/bin/env python3
"""
Main entry point for youtube_dlp_server package.
This allows running the server with: python -m youtube_dlp_server
"""

from . import main

if __name__ == "__main__":
    main()
